aboutsummaryrefslogtreecommitdiffstats
path: root/build_scripts
diff options
context:
space:
mode:
authorFriedemann Kleint <Friedemann.Kleint@qt.io>2020-11-02 16:11:52 +0100
committerFriedemann Kleint <Friedemann.Kleint@qt.io>2020-11-02 16:12:04 +0000
commit25180730194bec25f915f32ab846ea583fb1493f (patch)
tree9a73e0336ecf21e085d99d6a651c5547b9eb99f8 /build_scripts
parent6e3e7b9ca0548430aaa5e2555d6e02c64625fa3f (diff)
Rename PySide2 to PySide6
Adapt CMake files, build scripts, tests and examples. Task-number: PYSIDE-904 Change-Id: I845f7b006e9ad274fed5444ec4c1f9dbe176ff88 Reviewed-by: Christian Tismer <tismer@stackless.com>
Diffstat (limited to 'build_scripts')
-rw-r--r--build_scripts/config.py4
-rw-r--r--build_scripts/main.py8
-rw-r--r--build_scripts/platforms/unix.py4
-rw-r--r--build_scripts/platforms/windows_desktop.py8
-rw-r--r--build_scripts/setup_runner.py2
-rw-r--r--build_scripts/versions.py4
-rw-r--r--build_scripts/wheel_override.py4
-rw-r--r--build_scripts/wheel_utils.py4
8 files changed, 19 insertions, 19 deletions
diff --git a/build_scripts/config.py b/build_scripts/config.py
index 2e96efa7a..eb632fe3f 100644
--- a/build_scripts/config.py
+++ b/build_scripts/config.py
@@ -58,11 +58,11 @@ class Config(object):
self.invocation_type = None
# The type of the top-level build.
- # all - build shiboken6 module, shiboken6-generator and PySide2
+ # all - build shiboken6 module, shiboken6-generator and PySide6
# modules
# shiboken6 - build only shiboken6 module
# shiboken6-generator - build only the shiboken6-generator
- # pyside2 - build only PySide2 modules
+ # pyside6 - build only PySide6 modules
self.build_type = None
# The internal build type, used for internal invocations of
diff --git a/build_scripts/platforms/unix.py b/build_scripts/platforms/unix.py
index 482f2b82c..d92680a7b 100644
--- a/build_scripts/platforms/unix.py
+++ b/build_scripts/platforms/unix.py
@@ -175,14 +175,14 @@ def prepare_packages_posix(self, vars):
"{st_build_dir}/{st_package_name}/glue",
vars=vars)
- # <source>/pyside2/{st_package_name}/support/* ->
+ # <source>/pyside6/{st_package_name}/support/* ->
# <setup>/{st_package_name}/support/*
copydir(
f"{{build_dir}}/{PYSIDE}/{{st_package_name}}/support",
"{st_build_dir}/{st_package_name}/support",
vars=vars)
- # <source>/pyside2/{st_package_name}/*.pyi ->
+ # <source>/pyside6/{st_package_name}/*.pyi ->
# <setup>/{st_package_name}/*.pyi
copydir(
f"{{build_dir}}/{PYSIDE}/{{st_package_name}}",
diff --git a/build_scripts/platforms/windows_desktop.py b/build_scripts/platforms/windows_desktop.py
index 2f58c0cc9..058636d84 100644
--- a/build_scripts/platforms/windows_desktop.py
+++ b/build_scripts/platforms/windows_desktop.py
@@ -140,7 +140,7 @@ def prepare_packages_win32(self, vars):
vars=vars)
if config.is_internal_pyside_build():
- # <build>/pyside2/{st_package_name}/*.pdb ->
+ # <build>/pyside6/{st_package_name}/*.pdb ->
# <setup>/{st_package_name}
copydir(
f"{{build_dir}}/{PYSIDE}/{{st_package_name}}",
@@ -186,14 +186,14 @@ def prepare_packages_win32(self, vars):
"{st_build_dir}/{st_package_name}/glue",
vars=vars)
- # <source>/pyside2/{st_package_name}/support/* ->
+ # <source>/pyside6/{st_package_name}/support/* ->
# <setup>/{st_package_name}/support/*
copydir(
f"{{build_dir}}/{PYSIDE}/{{st_package_name}}/support",
"{st_build_dir}/{st_package_name}/support",
vars=vars)
- # <source>/pyside2/{st_package_name}/*.pyi ->
+ # <source>/pyside6/{st_package_name}/*.pyi ->
# <setup>/{st_package_name}/*.pyi
copydir(
"{build_dir}/{PYSIDE}/{st_package_name}",
@@ -367,7 +367,7 @@ def copy_qt_artifacts(self, copy_pdbs, vars):
# In debug_and_release case, choosing which files to copy
# is more difficult. We want to copy only the files that
- # match the PySide2 build type. So if PySide2 is built in
+ # match the PySide6 build type. So if PySide6 is built in
# debug mode, we want to copy only Qt debug libraries
# (ending with "d.dll"). Or vice versa. The problem is that
# some libraries have "d" as the last character of the
diff --git a/build_scripts/setup_runner.py b/build_scripts/setup_runner.py
index 3b6c6e117..df62083ba 100644
--- a/build_scripts/setup_runner.py
+++ b/build_scripts/setup_runner.py
@@ -129,7 +129,7 @@ class SetupRunner(object):
raise RuntimeError("Invalid '{}' option given to --build-type. "
.format(config.build_type))
- # Build everything: shiboken6, shiboken6-generator and PySide2.
+ # Build everything: shiboken6, shiboken6-generator and PySide6.
help_requested = '--help' in self.sub_argv or '-h' in self.sub_argv
if help_requested:
self.add_setup_internal_invocation(config.pyside_option_name)
diff --git a/build_scripts/versions.py b/build_scripts/versions.py
index ff340d479..f7312ebb4 100644
--- a/build_scripts/versions.py
+++ b/build_scripts/versions.py
@@ -38,6 +38,6 @@
#############################################################################
-PYSIDE = 'pyside2'
-PYSIDE_MODULE = 'PySide2'
+PYSIDE = 'pyside6'
+PYSIDE_MODULE = 'PySide6'
SHIBOKEN = 'shiboken6'
diff --git a/build_scripts/wheel_override.py b/build_scripts/wheel_override.py
index 0a631911b..6ade67bf6 100644
--- a/build_scripts/wheel_override.py
+++ b/build_scripts/wheel_override.py
@@ -100,8 +100,8 @@ class PysideBuildWheel(_bdist_wheel, DistUtilsCommandMixin):
# Slightly modified version of wheel's wheel_dist_name
# method, to add the Qt version as well.
# Example:
- # PySide2-5.6-5.6.4-cp27-cp27m-macosx_10_10_intel.whl
- # The PySide2 version is "5.6".
+ # PySide6-5.6-5.6.4-cp27-cp27m-macosx_10_10_intel.whl
+ # The PySide6 version is "5.6".
# The Qt version built against is "5.6.4".
wheel_version = "{}-{}".format(self._package_version, get_qt_version())
components = (_safer_name(self.distribution.get_name()), wheel_version)
diff --git a/build_scripts/wheel_utils.py b/build_scripts/wheel_utils.py
index 0b15c1a89..e4cd1bcfa 100644
--- a/build_scripts/wheel_utils.py
+++ b/build_scripts/wheel_utils.py
@@ -79,7 +79,7 @@ def get_qt_version():
@memoize
def get_package_version():
- """ Returns the version string for the PySide2 package. """
+ """ Returns the version string for the PySide6 package. """
setup_script_dir = os.getcwd()
pyside_version_py = os.path.join(
setup_script_dir, "sources", PYSIDE, "pyside_version.py")
@@ -112,7 +112,7 @@ def macos_qt_min_deployment_target():
@memoize
def macos_pyside_min_deployment_target():
"""
- Compute and validate PySide2 MACOSX_DEPLOYMENT_TARGET value.
+ Compute and validate PySide6 MACOSX_DEPLOYMENT_TARGET value.
Candidate sources that are considered:
- setup.py provided value
- maximum value between minimum deployment target of the
diff --git a/build_scripts/main.py b/build_scripts/main.py
index 99fdd286c..a1a697e3b 100644
--- a/build_scripts/main.py
+++ b/build_scripts/main.py
@@ -419,7 +419,7 @@ class PysideInstallLib(_install_lib):
def install(self):
"""
Installs files from build/xxx directory into final
- site-packages/PySide2 directory.
+ site-packages/PySide6 directory.
"""
if os.path.isdir(self.build_dir):
@@ -1115,7 +1115,7 @@ class PysideBuild(_build, DistUtilsCommandMixin):
pyside_libs.extend(executables)
# Update rpath in PySide2 libs
for srcname in pyside_libs:
srcpath = os.path.join(package_path, srcname)
if os.path.isdir(srcpath) or os.path.islink(srcpath):
@@ -1156,7 +1156,7 @@ class PysideRstDocs(Command, DistUtilsCommandMixin):
raise DistutilsSetupError("Sphinx not found - aborting")
self.html_dir = "html"
- # creating directories html/pyside2/shiboken6
+ # creating directories html/pyside6/shiboken6
try:
if not os.path.isdir(self.html_dir):
os.mkdir(self.html_dir)
@@ -1169,7 +1169,7 @@ class PysideRstDocs(Command, DistUtilsCommandMixin):
os.mkdir(out_shiboken)
self.out_dir = out_shiboken
# We know that on the shiboken step, we already created the
- # 'pyside2' directory
+ # 'pyside6' directory
elif self.name == PYSIDE:
self.out_dir = os.path.join(self.html_dir, PYSIDE)
except:
@@ -1115,7 +1115,7 @@ class PysideBuild(_build, DistUtilsCommandMixin):
pyside_libs.extend(executables)
- # Update rpath in PySide2 libs
+ # Update rpath in PySide6 libs
for srcname in pyside_libs:
srcpath = os.path.join(package_path, srcname)